@@ -6,6 +6,7 @@ Enjoy using!
 
 from .utils import exceptions, generator, headers, objects
 from .client import Client
+from .socket import Socket
 
 from os import system as s
 from colored import fore
@@ -16,10 +17,10 @@ __title__ = 'projectZ.py'
 __author__ = 'Xsarz'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2023 Xsarz'
-__version__ = '1.0'
+__version__ = '1.1'
 
 def init():
-	__newest__ = __version__#loads(get("").text)["info"]["version"]
+	__newest__ = loads(get("https://pypi.org/pypi/projectZ.py/json").text)["info"]["version"]
 	if __version__ != __newest__:
 		s('cls || clear')
 		print(fore.ORANGE_1, f'{__title__} made by {__author__}\nPlease update the library. Your version: {__version__}  A new version:{__newest__}', fore.WHITE)
